@@ -6,9 +6,13 @@ use strict;
 use warnings;
 
 use Carp;
-use Exporter qw{ import };
+use Exporter;
 
-our $VERSION = '0.005_02';
+# Beause the Perl 5.6 Exporter does not export import().
+BEGIN {
+    *import	= \&Exporter::import;
+}
+our $VERSION = '0.005_03';
 
 our @EXPORT_OK = qw{ __any };
 
